@@ -18,8 +18,11 @@
 #'
 #' message(word_wrap("Much too long string for just one line!", 15))
 #'
+#' @importFrom stats na.omit
 #' @export
 word_wrap <- function(labels, wrap, linesep = NULL) {
+  # check if labels have NA values and remove them
+  if (anyNA(labels)) labels <- as.character(stats::na.omit(labels))
   # check for valid value
   if (is.null(labels) || length(labels) == 0) return(NULL)
   # infinite wrap? then return labels
